#!/bin/bash
# packager           : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# homepage           : http://sourceforge.net/projects/libxosd
# source location    : http://freefr.dl.sourceforge.net/sourceforge/libxosd/xosd-2.2.14.tar.gz
# last revised       : 21.9.2009
# dep                : 

softname='libxosd'
softnamesrc='xosd'
softversion='2.2.14'
packageversion='1fb'

arch='i486'
cpu='i686'

prefix=/usr

# log
(

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/$softnamesrc-$softversion.tar.gz"
src="$buildir/$softnamesrc-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://freefr.dl.sourceforge.net/sourceforge/libxosd/$softnamesrc-$softversion.tar.gz

# prepare the build result directory
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc
       |-----handy-ruler------------------------------------------------------|
libxosd: libxosd (Displays text on your screen)
libxosd:
libxosd: XOSD is a simple library to display shaped text on your X display, 
libxosd: like a TV on-screen display. It also contains an example program 
libxosd: that can display system logs overlaid on your desktop.
libxosd: 
libxosd: 
libxosd:
libxosd: 
libxosd:
libxosd: 
EOF

# check if source is present
if [ -f $softnamesrc-$softversion.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
tar xvzf $srcpkg
cd $src

# build
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

./configure \
	--program-prefix="" \
	--program-suffix="" \
	--prefix="/usr" \
	--sysconfdir="/etc" \
	--localstatedir="/var" \
	--mandir="/usr/man" \
	--infodir="/usr/info" \
	--enable-static="no" \
	--enable-shared="yes" \
	--build=$arch-slackware-linux || exit

make 
make install DESTDIR=$dest

# add 'default' files
    mkdir -p $dest/usr/doc/$softname-$softversion
    cp -a \
      INSTALL README COPYING AUTHORS ChangeLog\
      $dest/usr/doc/$softname-$softversion

#  strip
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# compress man pages
( cd $dest/$prefix/man
  find . -name "*.?" | xargs gzip -9
)

# SalixBuild
cd $buildir
cp build-$softname.sh $dest/$prefix/src/$softname-$softversion

# set target permissions
chown -R root.root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work
cd $dest
makepkg -l y -c n $dest.txz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.txz > $package.md5

# .dep
cd $buildir
echo -e "libX11,libXau,libXdmcp,libXext,libXinerama,libxcb" > $package.dep

# .src
echo http://zenwalk.pinguix.com/user-accounts/bip/divers/salix/l/libxosd/source/build-libxosd.sh > $package.src
echo $source >> $package.src

# erase 
rm -rf $src
rm -rf $dest

# log
) 2>&1 | tee "$softname-$softversion-build.log"
